@@ -34,13 +34,37 @@ def mix_audios(
     audio_path_1: str,
     audio_path_2: str,
     path_out: str,
-    duration: str = 'longest',
+    duration: Optional[str] = 'longest',
     debug: bool = False
 ) -> bool:
-    sh.sh(
-        'ffmpeg -y -i {} -i {} -filter_complex amix=inputs=2:duration={} {}'.format(audio_path_1, audio_path_2, duration, path_out),
-        debug=debug
-    )
+    cmd = 'ffmpeg -y -i {} -i {} -filter_complex amix=inputs=2'.format(audio_path_1, audio_path_2)
+
+    if duration:
+        cmd += ':duration={}'.format(duration)
+
+    cmd += ' ' + path_out
+    sh.sh(cmd, debug=debug)
+
+    return path.exists(path_out)
+
+def mix_multiple_audios(
+    audio_paths: List[str],
+    path_out: str,
+    duration: Optional[str] = 'longest',
+    debug: bool = False
+) -> bool:
+    cmd = 'ffmpeg -y'
+
+    for audio_path in audio_paths:
+        cmd += ' -i ' + sh.path(audio_path)
+
+    cmd += ' -filter_complex amix=inputs=' + str(len(audio_paths))
+
+    if duration:
+        cmd += ':duration={}'.format(duration)
+
+    cmd += ' ' + path_out
+    sh.sh(cmd, debug=debug)
 
     return path.exists(path_out)
 
@@ -64,6 +88,15 @@ def reencode_aac(
 
     return path.exists(path_out)
 
+def reencode(
+    path_in: str,
+    path_out: str,
+    debug: bool = False
+) -> bool:
+    sh.sh('ffmpeg -y -i {} {}'.format(path_in, path_out), debug=debug)
+
+    return path.exists(path_out)
+
 def modify_audio(
     path_in: str,
     path_out: str,
@@ -319,6 +352,10 @@ def concat_videos_copy(
 
     return path.exists(out_path)
 
+#aliases
+concat_copy = concat_videos_copy
+concat_audios_copy = concat_videos_copy
+
 def concat_videos_reencode(
     in_paths: List[str],
     out_path: str,
